@@ -875,7 +875,14 @@ class BaseExperiment:
                     for file in os.listdir(f'{jsonlogdir}/{model_type_dir}/{metadata}/{version}'):
                         with open(f'{jsonlogdir}/{model_type_dir}/{metadata}/{version}/{file}', "r") as json_file:
                             logs = json.load(json_file)
-                            val_score = logs[val_metric] if isinstance(logs[val_metric], float) else logs[val_metric][-1]
+                            val_score = logs[val_metric] if isinstance(logs[val_metric], float) else logs[val_metric][-1][-1]
+                            if isinstance(logs[val_metric], float):
+                                val_score = logs[val_metric]
+                            elif isinstance(logs[val_metric][-1], float):
+                                val_score = logs[val_metric][-1]
+                            else:
+                                val_score = logs[val_metric][-1][-1]
+                            
                             if best_val is None:
                                 best_val = val_score
                                 best_path = file
@@ -897,7 +904,8 @@ class BaseExperiment:
                             info = {val_metric : best_val}
         if not fetch_only_dir:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}' 
-            ckpt_name = f'{ckpt_path}/{str(best_path).replace(".json", "")}' 
+            best_path_name = str(best_path).replace(".json", "")
+            ckpt_name = f'{ckpt_path}/{best_path_name}' 
             extension_candidates = [".ckpt", ".sav"]
             for extension_type in extension_candidates:
                 ckpt = ckpt_name + extension_type
